@@ -154,7 +154,8 @@ static AtkRoleItem role_items [] =
   { ATK_ROLE_PARAGRAPH, N_("paragraph")},
   { ATK_ROLE_APPLICATION, N_("application")},
   { ATK_ROLE_AUTOCOMPLETE, N_("autocomplete")},
-  { ATK_ROLE_EDITBAR, N_("edit bar")}
+  { ATK_ROLE_EDITBAR, N_("edit bar")},
+  { ATK_ROLE_EMBEDDED, N_("embedded component")}
 };
 
 static void            atk_object_class_init        (AtkObjectClass  *klass);
@@ -676,9 +677,10 @@ atk_object_get_role (AtkObject *accessible)
  * @accessible: an #AtkObject
  *
  * Gets the layer of the accessible.
- * DEPRECATED: use atk_component_get_layer instead!
  *
  * Returns: an #AtkLayer which is the layer of the accessible
+ *
+ * @Deprecated: Use atk_component_get_layer instead.
  **/
 AtkLayer
 atk_object_get_layer (AtkObject *accessible) 
@@ -700,11 +702,12 @@ atk_object_get_layer (AtkObject *accessible)
  *
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
- * DEPRECATED: use atk_component_get_mdi_zorder instead!
  *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
  * container.
+ *
+ * @Deprecated: Use atk_component_get_mdi_zorder instead.
  **/
 gint
 atk_object_get_mdi_zorder (AtkObject *accessible) 
@@ -1240,7 +1243,7 @@ static void
 atk_object_notify (GObject     *obj,
                    GParamSpec  *pspec)
 {
-  AtkPropertyValues values = { 0, };
+  AtkPropertyValues values = { NULL, };
 
   g_value_init (&values.new_value, pspec->value_type);
   g_object_get_property (obj, pspec->name, &values.new_value);
